==> react-formbuild-component-3.3.0.tgz: package/src/field/Select.js <==
import React, {Fragment, Component} from 'react';
import PropTypes from 'prop-types';
import Select, {components} from 'react-select';
import {
    FormGroup,
    Label,
    Row,
    Col, UncontrolledTooltip
} from 'reactstrap';
import Loading from '../Loading';
import {TextField} from './index';
import {
    noPadding,
    styleInvalid,
    styleValid,
    small,
    flexR,
    toolTip,
    padding,
    toolTipIcon,
    smallAlt
} from '../common/styles/index';
import OptionsService from "../services/network/fetchSelectOptions";


class SelectInput extends Component {
    static propTypes = {
        label: PropTypes.string.isRequired,
        control: PropTypes.string.isRequired,
        options: PropTypes.arrayOf(PropTypes.shape({})),
        onChange: PropTypes.func.isRequired,
        onChangeOthers: PropTypes.func.isRequired,
        valueOthers: PropTypes.string,
        value: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.number
        ]),
        onInputChange: PropTypes.func,
        getValue: PropTypes.func,
        defaultOption: PropTypes.bool,
        placeholder: PropTypes.string,
        disabled: PropTypes.bool,
        filterOption: PropTypes.oneOfType([
            PropTypes.any
        ]),
        helpText: PropTypes.bool,
        error: PropTypes.shape.isRequired,
        searchAmount: PropTypes.number,
        token: PropTypes.string,
        source: PropTypes.arrayOf(PropTypes.shape({})),
        validateOnChange: PropTypes.func,
        onSetRef: PropTypes.func
    };

    static defaultProps = {
        source: [],
        searchAmount: 3,
        defaultOption: false,
        placeholder: '[Seleccione]',
        value: '',
        valueOthers: '',
        onInputChange: null,
        getValue: null,
        disabled: false,
        filterOption: null,
        helpText: null,
        token: 'An invalid Token',
        validateOnChange: null
    };

    constructor(props) {
        super(props);
        this.state = {
            options: this.props.options ? this.props.options : [],
            isSearching: false,
            result: ''
        }
        this.ref = React.createRef();
    }

    componentWillUpdate(nextProps, nextState, nextContext) {
        if (nextProps.options) {
            this.state.options = nextProps.options;
        }
    }

    componentDidMount() {
        if (this.props.onSetRef) {
            this.props.onSetRef(this.ref);
        }
    }

    handleInputChange(e) {
        if (this.props.source.length > 0) {
            this.timeout = setTimeout(() => {
                if (e !== undefined && this.props.source !== [] && e.length > this.props.searchAmount && !this.state.isSearching) {
                    this.setState({isSearching: true})
                    OptionsService.fetchOptions(this.props.token, e, this.props.source.query).then(result => {
                        if (result.message) {
                            this.setState({
                                options: ([{label: '[Opcion no encontrada]', value: null}]),
                                isSearching: false,
                                result: result.message
                            })
                        } else {
                            this.setState({
                                isSearching: false,
                                options: this.props.source.reducer(result),
                                result: ''
                            })
                        }
                    })
                }
            }, 500)
        }
    }

    render() {
        const customComponents = {
            NoOptionsMessage: props => (
                <components.NoOptionsMessage {...props}>
                    No se encontraron resultados&nbsp;
                </components.NoOptionsMessage>
            )
        };
        return (
            <FormGroup>
                <Row style={noPadding}>
                    <Col style={noPadding}>
                        <Fragment>
                            <Label
                                style={{...small, ...noPadding, ...flexR, ...padding}}>
                                <p
                                    style={noPadding}>
                                    {this.props.label + " "}
                                </p>
                                {this.props.helpText && (
                                    <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}
                                       id={'ref' + this.props.control}>
                                        {String.fromCharCode(0x24D8)}
                                    </p>
                                )}

                            </Label>
                            <Select
                                id={this.props.control}
                                value={this.props.value}
                                defaultValue={this.props.defaultOption ? {value: '', label: '[Todos]'} : false}
                                onChange={e => this.props.onChange(e)}
                                onInputChange={this.props.source.length > 0 ?
                                    e => this.handleInputChange(e) :
                                    this.props.onInputChange
                                }
                                options={this.state.options}
                                components={customComponents}
                                filterOption={this.props.filterOption}
                                isSearchable
                                isClearable
                                isDisabled={this.props.disabled}
                                placeholder={this.props.placeholder}
                                clearValueText="Limpiar Filtro"
                                isLoading={this.state.isSearching}
                                closeMenuOnSelect
                                ref={this.ref}
                            />
                            {this.props.helpText && (
                                <UncontrolledTooltip
                                    placement="top"
                                    target={'ref' + this.props.control}
                                    style={toolTip}>
                                    {this.props.helpText}
                                </UncontrolledTooltip>
                            )}
                            {this.state.isSearching && (
                                <Loading
                                    label="Estamos buscando tu consulta"
                                />
                            )}
                            {
                                (this.props.error.message !== '') &&
                                (
                                    <p style={this.props.error.status === 'valid' ? styleValid : styleInvalid}>
                                        {this.props.error.message + (this.state.result !== '' ? (' -> ' + this.state.result) : '')}
                                    </p>)
                            }
                        </Fragment>
                    </Col>
                    {
                        this.props.supportsWriteOthers && (
                            <div>
                                &nbsp;&nbsp;
                            </div>
                        )
                    }
                    {this.props.supportsWriteOthers && (
                        <Col style={noPadding}>
                            <TextField
                                name={`${this.props.control}Others`}
                                label={`Otro ${this.props.label}`}
                                value={this.props.valueOthers}
                                helpText={null}
                                disabled={value.value !== 'idAnother'}
                                onChange={e => this.props.onChangeOthers(e)}
                                error={this.props.error}
                                type={'textField'}/>
                        </Col>
                    )}
                </Row>

            </FormGroup>
        )
    }
}


export default SelectInput

==> react-formbuild-component-3.4.1.tgz: package/src/field/Select.js <==
import React, {Fragment, Component} from 'react';
import PropTypes from 'prop-types';
import Select, {components} from 'react-select';
import {
    FormGroup,
    Label,
    Row,
    Col, UncontrolledTooltip
} from 'reactstrap';
import {find, size} from 'lodash';
import Loading from '../Loading';
import {TextField} from './index';
import {
    noPadding,
    styleInvalid,
    styleValid,
    small,
    flexR,
    toolTip,
    padding,
    toolTipIcon,
    smallAlt
} from '../common/styles/index';
import OptionsService from "../services/network/fetchSelectOptions";


class SelectInput extends Component {
    static propTypes = {
        label: PropTypes.string.isRequired,
        control: PropTypes.string.isRequired,
        options: PropTypes.arrayOf(PropTypes.shape({})),
        onChange: PropTypes.func.isRequired,
        onChangeOthers: PropTypes.func.isRequired,
        valueOthers: PropTypes.string,
        value: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.number
        ]),
        onInputChange: PropTypes.func,
        getValue: PropTypes.func,
        defaultOption: PropTypes.bool,
        placeholder: PropTypes.string,
        disabled: PropTypes.bool,
        filterOption: PropTypes.oneOfType([
            PropTypes.any
        ]),
        helpText: PropTypes.bool,
        error: PropTypes.shape.isRequired,
        searchAmount: PropTypes.number,
        token: PropTypes.string,
        source: PropTypes.arrayOf(PropTypes.shape({})),
        validateOnChange: PropTypes.func,
        onSetRef: PropTypes.func
    };

    static defaultProps = {
        source: [],
        searchAmount: 3,
        defaultOption: false,
        placeholder: '[Seleccione]',
        value: '',
        valueOthers: '',
        onInputChange: null,
        getValue: null,
        disabled: false,
        filterOption: null,
        helpText: null,
        token: 'An invalid Token',
        validateOnChange: null
    };

    constructor(props) {
        super(props);
        this.state = {
            options: this.props.options ? this.props.options : [],
            isSearching: false,
            result: ''
        }
        this.ref = React.createRef();
    }

    componentWillUpdate(nextProps, nextState, nextContext) {
        if (nextProps.options) {
            this.state.options = nextProps.options;
        }
    }

    componentDidMount() {
        if (this.props.onSetRef) {
            this.props.onSetRef(this.ref);
        }
    }

    handleInputChange(e) {
        if (size(this.props.source)) {
            const q = this.props.source.searchAmount ? this.props.source.searchAmount : 2;
            this.timeout = setTimeout(() => {
                if (e !== undefined
                        && this.props.source !== []
                        && e.length > q
                        && !this.state.isSearching
                ) {
                    this.setState({isSearching: true})
                    OptionsService.fetchOptions(this.props.token, e, this.props.source.query).then(result => {
                        if (result.message) {
                            this.setState({
                                options: ([{label: '[Opcion no encontrada]', value: null}]),
                                isSearching: false,
                                result: result.message
                            })
                        } else {
                            this.setState({
                                isSearching: false,
                                options: this.props.source.reducer(result),
                                result: ''
                            })
                        }
                    })
                }
            }, 500)
        }
    }

    render() {
        const customComponents = {
            NoOptionsMessage: props => (
                <components.NoOptionsMessage {...props}>
                    No se encontraron resultados&nbsp;
                </components.NoOptionsMessage>
            )
        };
        return (
            <FormGroup>
                <Row style={noPadding}>
                    <Col style={noPadding}>
                        <Fragment>
                            <Label
                                style={{...small, ...noPadding, ...flexR, ...padding}}>
                                <p
                                    style={noPadding}>
                                    {this.props.label + " "}
                                </p>
                                {this.props.helpText && (
                                    <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}
                                       id={'ref' + this.props.control}>
                                        {String.fromCharCode(0x24D8)}
                                    </p>
                                )}

                            </Label>
                            <Select
                                id={this.props.control}
                                value={this.props.value}
                                defaultValue={this.props.defaultOption ? {value: '', label: '[Todos]'} : false}
                                onChange={e => this.props.onChange(e)}
                                onInputChange={size(this.props.source) ?
                                    e => this.handleInputChange(e) :
                                    this.props.onInputChange
                                }
                                options={this.state.options}
                                components={customComponents}
                                filterOption={this.props.filterOption}
                                isSearchable
                                isClearable
                                isDisabled={this.props.disabled}
                                placeholder={this.props.placeholder}
                                clearValueText="Limpiar Filtro"
                                isLoading={this.state.isSearching}
                                closeMenuOnSelect
                                ref={this.ref}
                            />
                            {this.props.helpText && (
                                <UncontrolledTooltip
                                    placement="top"
                                    target={'ref' + this.props.control}
                                    style={toolTip}>
                                    {this.props.helpText}
                                </UncontrolledTooltip>
                            )}
                            {this.state.isSearching && (
                                <Loading
                                    label="Estamos buscando tu consulta"
                                />
                            )}
                            {
                                (this.props.error.message !== '') &&
                                (
                                    <p style={this.props.error.status === 'valid' ? styleValid : styleInvalid}>
                                        {this.props.error.message + (this.state.result !== '' ? (' -> ' + this.state.result) : '')}
                                    </p>)
                            }
                        </Fragment>
                    </Col>
                    {
                        this.props.supportsWriteOthers && (
                            <div>
                                &nbsp;&nbsp;
                            </div>
                        )
                    }
                    {this.props.supportsWriteOthers && (
                        <Col style={noPadding}>
                            <TextField
                                name={`${this.props.control}Others`}
                                label={`Otro ${this.props.label}`}
                                value={this.props.valueOthers}
                                helpText={null}
                                disabled={value.value !== 'idAnother'}
                                onChange={e => this.props.onChangeOthers(e)}
                                error={this.props.error}
                                type={'textField'}/>
                        </Col>
                    )}
                </Row>

            </FormGroup>
        )
    }
}


export default SelectInput
